@@ -188,8 +188,8 @@ class EmptyResponse(ClosableResponse):
         self,
         *,
         encoding: Optional[str] = None,
-        loads: Optional[Callable[[str], Any]] = None,
-        content_type: Optional[str] = "application/json",
+        loads: Optional[Callable[[str], Any]] = json.loads,
+        content_type: Optional[str] = None,
     ) -> Any:
         return None
 
